% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/composite.R
\name{get_weights}
\alias{get_weights}
\title{Get the set of weights for building the composite indicator}
\usage{
get_weights(data, method, ...)
}
\arguments{
\item{data}{data matrix of \strong{binary} elementary indicators (without missing values).}

\item{method}{method for getting the set of weights. Possible choices are:
\code{"equal"}, \code{"experts"} or \code{"irt"}. See Details.}

\item{...}{optional arguments for \code{\link[mirt:mirt]{mirt::mirt()}} function. See Details.}
}
\value{
vector of weights.
}
\description{
\code{get_weights} returns the weights for constructing the composite indicator.
}
\details{
This function returns a vector of weights, whose dimension is equal to the
number of elementary indicators in \code{data} (say, \eqn{Q}). Three choices are offered:
\itemize{
\item \code{"equal"}: each elementary indicator receives the same weight, equal to \eqn{1/Q};
\item \code{"experts"}: each elementary indicator receives a specific weight provided by experts;
\item \code{"irt"}: each elementary indicator receives a specific weights provided by the IRT framework.
Specifically, a unidimensional 2PL IRT model is estimated on \code{data} through \code{\link[mirt:mirt]{mirt::mirt()}} function,
for which possible additional arguments can be provided (\code{...}), such as estimation algorithm,
numerical optimiser, convergence threshold, etc. Once the model is fitted, weights are computed
by rescaling the estimated discrimination parameters (in such a way they sum to 1).
\emph{Note: for the moment, IRT weights can be obtained only when the elementary indicators are all binary.}
}
}
\examples{
\dontrun{
if(interactive()){
  mock_data_core_variants <- unnest(mock_data_core, varianti, keep_empty = TRUE)
  out_companies <- ind_all(data = mock_data_core,
                          data_ind8 = mock_data_core_variants,
                          emergency_name = "coronavirus",
                          target_unit = "companies")
  data_matrix <- create_indicator_matrix(out_companies)
  w <- get_weights(data_matrix, method = "equal")
 }
}
}
\seealso{
\code{\link[mirt]{mirt}}, \code{\link[mirt]{MDISC}}
}
